#!/usr/bin/env python3

from typing import Final

NO_SUCH_FILE_OR_DIRECTORY_ERROR: Final[int] = 300
SINGLE_FILE_ERROR: Final[int] = 301
MULTIPASS_GENERIC_ERROR: Final[int] = 302
MULTIPASS_NOT_INSTALLED_ERROR: Final[int] = 303
INVALID_INSTANCE_NAME_ERROR: Final[int] = 304
NO_SUPPORTED_REQUIREMENTS_FILE_FOUND_ERROR: Final[int] = 305
SCRIPT_FOLDER_NOT_FOUND_ERROR: Final[int] = 306
